@@ -1,7 +1,12 @@
-from Pythonic.record_function import Record, Function
+from Pythonic.record_function import Record, Function, PipeRecord
+import time
+
+from PyQt5.QtCore import QObject
+from PyQt5.QtCore import pyqtSignal
 
 class OperationFunction(Function):
 
+
     def __init__(self, config, b_debug, row, column):
         super().__init__(config, b_debug, row, column)
 
@@ -9,7 +14,8 @@ class OperationFunction(Function):
 
         log_state, code_input, custom_edit_state, cmd = self.config
 
-        proc_dict = {'record' : record, 'input' : None, 'output' : None, 'log_txt' : None}
+        proc_dict = {'record' : record, 'callback' : self.callback, 'pos' : self.getPos, 
+                'input' : None, 'output' : None, 'log_txt' : None}
                         
 
         exec_string = 'input = record\r\n'
@@ -20,6 +26,20 @@ class OperationFunction(Function):
 
         exec(exec_string, proc_dict)
 
+
+        """
+        n_cnt = 0
+
+        while True:
+            n_cnt += 1
+            # switch grid
+            #ret_data = PipeRecord(self.getPos(), (1, self.row+1, self.column), n_cnt)
+            my_text = 'Hello log'
+            ret_data = PipeRecord(self.getPos(), (self.row+1, self.column), n_cnt, True, my_text)
+            self.callback(ret_data)
+            time.sleep(2)
+        """
+
         output = proc_dict['output']
         log_txt = proc_dict['log_txt']
         if log_txt:
