@@ -1,17 +1,12 @@
-from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, pyqtSlot, QVariant
-from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout, QLineEdit, QPushButton, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox, QStackedWidget, QFileDialog
+from PyQt5.QtCore import QVariant
+from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QPushButton, QLabel, QWidget,
+                            QComboBox, QCheckBox, QFileDialog, QLineEdit)
 from PyQt5.QtCore import QCoreApplication as QC
-from pythonic_binance.client import Client
-import pandas as pd
-import os.path, datetime, logging, requests, json, pickle
-from time import sleep
+import logging
 from Pythonic.elementeditor import ElementEditor
-from Pythonic.record_function import Record, Function
 from Pythonic.elementmaster import ElementMaster
+from Pythonic.elements.ml_svm_predict_func import MLSVM_PredictFunction
 from pathlib import Path
-from sys import getsizeof
-from sklearn import svm, preprocessing
-from sklearn.model_selection import train_test_split
 
 class MLSVM_Predict(ElementMaster):
 
@@ -29,9 +24,10 @@ class MLSVM_Predict(ElementMaster):
         scale_std           = True
         predict_val         = False
         filename            = None
+        rel_path            = False
         log_state           = False
 
-        self.config = scale_option, scale_mean, scale_std, predict_val, filename, log_state
+        self.config = scale_option, scale_mean, scale_std, predict_val, filename, rel_path, log_state
 
         super().__init__(self.row, self.column, self.pixmap_path, True, self.config)
         super().edit_sig.connect(self.edit)
@@ -58,7 +54,7 @@ class MLSVM_Predict(ElementMaster):
 
         # scale_option, scale_mean, scale_std, predict_val, filename, log_state
         self.scale_option, self.scale_mean, self.scale_std, self.predict_val, \
-                self.filename, self.log_state = self.config
+                self.filename, self.rel_path, self.log_state = self.config
 
         self.home_dict = str(Path.home())
 
@@ -104,13 +100,40 @@ class MLSVM_Predict(ElementMaster):
         self.conn_rest_layout = QVBoxLayout()
         self.confirm_button = QPushButton(QC.translate('', 'Ok'))
 
+        """
         self.filename_text = QLabel()
         self.filename_text.setWordWrap(True)
         
         self.file_button = QPushButton(QC.translate('', 'Select model file'))
         self.file_button.clicked.connect(self.openFileNameDialog)
+        """
 
+        self.filename_text = QLabel()
+        self.filename_text.setWordWrap(True)
+
+        self.file_button = QPushButton(QC.translate('', 'Select model output file'))
+        self.file_button.clicked.connect(self.openFileNameDialog)
         
+        self.relative_file_check = QWidget()
+        self.relative_file_check_layout = QHBoxLayout(self.relative_file_check)
+
+        self.relative_file_label = QLabel()
+        self.relative_file_label.setText(QC.translate('', 'Filename relative to $HOME.'))
+        self.relative_file_checkbox = QCheckBox()
+        self.relative_file_check_layout.addWidget(self.relative_file_checkbox)
+        self.relative_file_check_layout.addWidget(self.relative_file_label)
+        self.relative_file_check_layout.addStretch(1)
+
+        self.relative_filepath_input = QLineEdit()
+        self.relative_filepath_input.setPlaceholderText('my_folder/my_file')
+
+        self.file_input = QWidget()
+        self.file_input_layout = QVBoxLayout(self.file_input)
+        self.file_input_layout.addWidget(self.filename_text)
+        self.file_input_layout.addWidget(self.file_button)
+        self.file_input_layout.addWidget(self.relative_file_check)
+        self.file_input_layout.addWidget(self.relative_filepath_input)
+
         """
         output: prediction quality
         """
@@ -138,6 +161,7 @@ class MLSVM_Predict(ElementMaster):
         self.ml_svm_predict_edit.setMinimumHeight(450)
 
         # signals and slots
+        self.relative_file_checkbox.stateChanged.connect(self.toggleFileInput)
         self.scale_list.currentIndexChanged.connect(self.scaledIndexChanged)
         self.confirm_button.clicked.connect(self.ml_svm_predict_edit.closeEvent)
         self.ml_svm_predict_edit.window_closed.connect(self.edit_done)
@@ -150,8 +174,7 @@ class MLSVM_Predict(ElementMaster):
         self.conn_rest_layout.addWidget(self.scale_list)
         self.conn_rest_layout.addWidget(self.scale_input_area)
         self.conn_rest_layout.addWidget(self.last_value_line)
-        self.conn_rest_layout.addWidget(self.filename_text)
-        self.conn_rest_layout.addWidget(self.file_button)
+        self.conn_rest_layout.addWidget(self.file_input)
         self.conn_rest_layout.addStretch(1)
         self.conn_rest_layout.addWidget(self.help_text_2)
         self.conn_rest_layout.addWidget(self.log_line)
@@ -169,8 +192,29 @@ class MLSVM_Predict(ElementMaster):
         self.scale_std_checkbox.setChecked(self.scale_std)
         self.last_value_checkbox.setChecked(self.predict_val)
         self.log_checkbox.setChecked(self.log_state)
-        if self.filename:
-            self.filename_text.setText(self.filename)
+        self.relative_file_checkbox.setChecked(self.rel_path)
+        
+        if self.rel_path:
+            self.toggleFileInput(2)
+            if self.filename:
+                self.relative_filepath_input.setText(self.filename)
+        else:
+            self.toggleFileInput(0)
+            if self.filename:
+                self.filename_text.setText(self.filename)
+
+    def toggleFileInput(self, event):
+        logging.debug('MLSVM::toggleFileInput() called: {}'.format(event))
+        # 0 = FALSE, 2 = TRUE
+        if event: # TRUE
+            self.file_button.setDisabled(True)
+            self.relative_filepath_input.setDisabled(False)
+            self.filename_text.setText('')
+        else:
+            self.file_button.setDisabled(False)
+            self.relative_filepath_input.clear()
+            self.relative_filepath_input.setDisabled(True)
+            self.relative_filepath_input.setPlaceholderText('my_folder/my_file')
 
     def scaledIndexChanged(self, event):
 
@@ -202,63 +246,16 @@ class MLSVM_Predict(ElementMaster):
         scale_mean          = self.scale_center_checkbox.isChecked()
         scale_std           = self.scale_std_checkbox.isChecked()
         predict_val         = self.last_value_checkbox.isChecked()
-        filename            = self.filename
         log_state           = self.log_checkbox.isChecked()
+        rel_path            = self.relative_file_checkbox.isChecked()
+        if rel_path:
+            filename        = self.relative_filepath_input.text()
+        else:
+            filename        = self.filename
 
-        self.config = scale_option, scale_mean, scale_std, predict_val, filename, log_state
+        if filename == '':
+            filename = None
+
+        self.config = scale_option, scale_mean, scale_std, predict_val, filename, rel_path, log_state
         
         self.addFunction(MLSVM_PredictFunction)
-
-class MLSVM_PredictFunction(Function):
-
-    def __init(self, config, b_debug, row, column):
-
-        super().__init__(config, b_debug, row, column)
-        logging.debug('MLSVM_PredictFunction::__init__() called')
-
-    def execute(self, record):
-
-        scale_option, scale_mean, scale_std, predict_val, filename, log_state = self.config
-        b_open_succeeded = True
-
-        if filename:
-            try:
-                with open(filename, 'rb') as f:
-                    clf = pickle.load(f)
-            except Exception as e:
-                # not writeable?
-                log_txt = '{SVM Predict}            Error opening model'
-                record = None
-                b_open_succeeded = False
-        else:
-            b_open_succeeded = False
-            log_txt = '{SVM Predict}            No model file specified'
-
-        if b_open_succeeded:
-            if isinstance(record, (list, tuple, pd.DataFrame)):
-                # scaling option only here available
-                if not isinstance(record, pd.DataFrame):
-                    record = pd.DataFrame(record)
-
-                record = preprocessing.scale(record, with_mean=scale_mean, with_std=scale_std)
-                record = clf.predict(record)
-            elif record:
-                # when only one value is passed
-                predict_val = False
-                record = pd.DataFrame([record])
-                record = clf.predict([record])
-            else:
-                log_txt = '{SVM Predict}            No input specified'
-
-                
-            if predict_val:
-                # predict only last value
-                record = pd.DataFrame([record[-1]])
-                record = clf.predict(record)
-
-            log_txt = '{{SVM Predict}}            Predicted {} value'.format(len(record))
-
-        result = Record(self.getPos(), (self.row +1, self.column), record,
-                 log=log_state, log_txt=log_txt)
-        
-        return result
